=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2006-06-29 16:30:47 +0000
+++ bzrlib/builtins.py	2006-07-02 02:08:10 +0000
@@ -800,15 +800,17 @@
         tree = WorkingTree.open_containing(dir)[0]
         tree.lock_write()
         try:
-            if tree.last_revision() == tree.branch.last_revision():
+            last_rev = tree.last_revision() 
+            if last_rev == tree.branch.last_revision():
                 # may be up to date, check master too.
                 master = tree.branch.get_master_branch()
-                if master is None or master.last_revision == tree.last_revision():
-                    note("Tree is up to date.")
-                    return
+                if master is None or last_rev == master.last_revision():
+                    revno = tree.branch.revision_id_to_revno(last_rev)
+                    note("Tree is up to date at revision %d." % (revno,))
+                    return 0
             conflicts = tree.update()
-            note('Updated to revision %d.' %
-                 (tree.branch.revision_id_to_revno(tree.last_revision()),))
+            revno = tree.branch.revision_id_to_revno(tree.last_revision())
+            note('Updated to revision %d.' % (revno,))
             if conflicts != 0:
                 return 1
             else:

=== modified file 'bzrlib/tests/blackbox/test_update.py'
--- bzrlib/tests/blackbox/test_update.py	2006-03-05 11:48:54 +0000
+++ bzrlib/tests/blackbox/test_update.py	2006-07-02 02:08:10 +0000
@@ -29,14 +29,21 @@
     def test_update_standalone_trivial(self):
         self.runbzr("init")
         out, err = self.runbzr('update')
-        self.assertEqual('Tree is up to date.\n', err)
+        self.assertEqual('Tree is up to date at revision 0.\n', err)
         self.assertEqual('', out)
 
     def test_update_up_to_date_light_checkout(self):
         self.make_branch_and_tree('branch')
         self.runbzr('checkout --lightweight branch checkout')
         out, err = self.runbzr('update checkout')
-        self.assertEqual('Tree is up to date.\n', err)
+        self.assertEqual('Tree is up to date at revision 0.\n', err)
+        self.assertEqual('', out)
+
+    def test_update_up_to_date_checkout(self):
+        self.make_branch_and_tree('branch')
+        self.run_bzr('checkout', 'branch', 'checkout')
+        out, err = self.run_bzr('update', 'checkout')
+        self.assertEqual('Tree is up to date at revision 0.\n', err)
         self.assertEqual('', out)
 
     def test_update_out_of_date_standalone_tree(self):

